Index: cpukit/libdrvmgr/drvmgr_by_id.c
===================================================================
--- cpukit/libdrvmgr/drvmgr_by_id.c	(revision bf2c3f8baf2fcf8518b23eee9f886a12811dd5f9)
+++ cpukit/libdrvmgr/drvmgr_by_id.c	(revision bb2f2200aa144f96bdb3172bdaedf4ec82eac82b)
@@ -14,5 +14,5 @@
 struct drvmgr_drv *drvmgr_drv_by_id(uint64_t id)
 {
-	struct rtems_driver_manager *mgr = &drv_mgr;
+	struct drvmgr *mgr = &drvmgr;
 	struct drvmgr_drv *drv = NULL;
 
Index: cpukit/libdrvmgr/drvmgr_by_name.c
===================================================================
--- cpukit/libdrvmgr/drvmgr_by_name.c	(revision bf2c3f8baf2fcf8518b23eee9f886a12811dd5f9)
+++ cpukit/libdrvmgr/drvmgr_by_name.c	(revision bb2f2200aa144f96bdb3172bdaedf4ec82eac82b)
@@ -15,5 +15,5 @@
 struct drvmgr_drv *drvmgr_drv_by_name(const char *name)
 {
-	struct rtems_driver_manager *mgr = &drv_mgr;
+	struct drvmgr *mgr = &drvmgr;
 	struct drvmgr_drv *drv = NULL;
 
Index: cpukit/libdrvmgr/drvmgr_for_each_dev.c
===================================================================
--- cpukit/libdrvmgr/drvmgr_for_each_dev.c	(revision bf2c3f8baf2fcf8518b23eee9f886a12811dd5f9)
+++ cpukit/libdrvmgr/drvmgr_for_each_dev.c	(revision bb2f2200aa144f96bdb3172bdaedf4ec82eac82b)
@@ -25,5 +25,5 @@
 	pos = 0;
 	memset(&buses[0], 0, sizeof(buses));
-	buses[pos++] = drv_mgr.root_dev.bus; 	/* Get root bus */
+	buses[pos++] = drvmgr.root_dev.bus; 	/* Get root bus */
 
 	for (i = 0, bus = buses[0]; buses[i]; i++, bus = buses[i]) {
@@ -53,5 +53,5 @@
 
 	/* Get first device */
-	dev = drv_mgr.root_dev.bus->children;
+	dev = drvmgr.root_dev.bus->children;
 
 	while (dev) {
@@ -66,5 +66,5 @@
 				/* Step up one level... back to parent bus */
 				dev = dev->parent->dev;
-				if (dev == &drv_mgr.root_dev)
+				if (dev == &drvmgr.root_dev)
 					break;
 				goto next_dev;
@@ -90,5 +90,5 @@
 
 	/* Get Root Device */
-	if (drv_mgr.root_dev.bus->children != NULL) {
+	if (drvmgr.root_dev.bus->children != NULL) {
 		if (options & DRVMGR_FED_BF)
 			ret = drvmgr_for_each_dev_breadth(func, arg);
Index: cpukit/libdrvmgr/drvmgr_internal.h
===================================================================
--- cpukit/libdrvmgr/drvmgr_internal.h	(revision bf2c3f8baf2fcf8518b23eee9f886a12811dd5f9)
+++ cpukit/libdrvmgr/drvmgr_internal.h	(revision bb2f2200aa144f96bdb3172bdaedf4ec82eac82b)
@@ -11,5 +11,5 @@
  *  internally by Driver Manager routines.
  */
-struct rtems_driver_manager {
+struct drvmgr {
 	int	level;
 	int	initializing_objs;
@@ -46,5 +46,5 @@
 };
 
-extern struct rtems_driver_manager drv_mgr;
+extern struct drvmgr drvmgr;
 
 extern void _DRV_Manager_Lock(void);
Index: cpukit/libdrvmgr/drvmgr_lock.c
===================================================================
--- cpukit/libdrvmgr/drvmgr_lock.c	(revision bf2c3f8baf2fcf8518b23eee9f886a12811dd5f9)
+++ cpukit/libdrvmgr/drvmgr_lock.c	(revision bb2f2200aa144f96bdb3172bdaedf4ec82eac82b)
@@ -14,10 +14,10 @@
 void _DRV_Manager_Lock(void)
 {
-	rtems_semaphore_obtain(drv_mgr.lock, RTEMS_WAIT, RTEMS_NO_TIMEOUT);
+	rtems_semaphore_obtain(drvmgr.lock, RTEMS_WAIT, RTEMS_NO_TIMEOUT);
 }
 
 void _DRV_Manager_Unlock(void)
 {
-	rtems_semaphore_release(drv_mgr.lock);
+	rtems_semaphore_release(drvmgr.lock);
 }
 
@@ -31,5 +31,5 @@
 		RTEMS_DEFAULT_ATTRIBUTES,
 		0,
-		&drv_mgr.lock);
+		&drvmgr.lock);
 	if (rc != RTEMS_SUCCESSFUL)
 		return -1;
Index: cpukit/libdrvmgr/drvmgr_print.c
===================================================================
--- cpukit/libdrvmgr/drvmgr_print.c	(revision bf2c3f8baf2fcf8518b23eee9f886a12811dd5f9)
+++ cpukit/libdrvmgr/drvmgr_print.c	(revision bb2f2200aa144f96bdb3172bdaedf4ec82eac82b)
@@ -40,5 +40,5 @@
 void drvmgr_print_devs(unsigned int options)
 {
-	struct rtems_driver_manager *mgr = &drv_mgr;
+	struct drvmgr *mgr = &drvmgr;
 	char *parg;
 
@@ -105,5 +105,5 @@
 void drvmgr_print_mem(void)
 {
-	struct rtems_driver_manager *mgr = &drv_mgr;
+	struct drvmgr *mgr = &drvmgr;
 	struct drvmgr_bus *bus;
 	struct drvmgr_dev *dev;
@@ -181,5 +181,5 @@
 void drvmgr_summary(void)
 {
-	struct rtems_driver_manager *mgr = &drv_mgr;
+	struct drvmgr *mgr = &drvmgr;
 	struct drvmgr_bus *bus;
 	struct drvmgr_dev *dev;
@@ -421,5 +421,5 @@
 void drvmgr_info_devs(unsigned int options)
 {
-	struct rtems_driver_manager *mgr = &drv_mgr;
+	struct drvmgr *mgr = &drvmgr;
 	struct drvmgr_dev *dev;
 
@@ -432,5 +432,5 @@
 void drvmgr_info_drvs(unsigned int options)
 {
-	struct rtems_driver_manager *mgr = &drv_mgr;
+	struct drvmgr *mgr = &drvmgr;
 	struct drvmgr_drv *drv;
 
@@ -445,5 +445,5 @@
 void drvmgr_info_buses(unsigned int options)
 {
-	struct rtems_driver_manager *mgr = &drv_mgr;
+	struct drvmgr *mgr = &drvmgr;
 	struct drvmgr_bus *bus;
 
Index: cpukit/libdrvmgr/drvmgr_translate.c
===================================================================
--- cpukit/libdrvmgr/drvmgr_translate.c	(revision bf2c3f8baf2fcf8518b23eee9f886a12811dd5f9)
+++ cpukit/libdrvmgr/drvmgr_translate.c	(revision bb2f2200aa144f96bdb3172bdaedf4ec82eac82b)
@@ -138,9 +138,9 @@
 	rev = (~options) & 1;
 	if ((options == CPUMEM_TO_DMA) || (options == DMAMEM_FROM_CPU)) {
-		from = drv_mgr.root_dev.bus;
+		from = drvmgr.root_dev.bus;
 		to = dev->parent;
 	} else { /* CPUMEM_FROM_DMA || DMAMEM_TO_CPU */
 		from = dev->parent;
-		to = drv_mgr.root_dev.bus;
+		to = drvmgr.root_dev.bus;
 	}
 
Index: cpukit/libdrvmgr/drvmgr_unregister.c
===================================================================
--- cpukit/libdrvmgr/drvmgr_unregister.c	(revision bf2c3f8baf2fcf8518b23eee9f886a12811dd5f9)
+++ cpukit/libdrvmgr/drvmgr_unregister.c	(revision bb2f2200aa144f96bdb3172bdaedf4ec82eac82b)
@@ -43,5 +43,5 @@
 int drvmgr_bus_unregister(struct drvmgr_bus *bus)
 {
-	struct rtems_driver_manager *mgr = &drv_mgr;
+	struct drvmgr *mgr = &drvmgr;
 	struct drvmgr_list *list;
 
@@ -79,5 +79,5 @@
 int drvmgr_dev_drv_separate(struct drvmgr_dev *dev)
 {
-	struct rtems_driver_manager *mgr = &drv_mgr;
+	struct drvmgr *mgr = &drvmgr;
 	struct drvmgr_dev *subdev, **pprev;
 	int rc;
@@ -150,5 +150,5 @@
 int drvmgr_dev_unregister(struct drvmgr_dev *dev)
 {
-	struct rtems_driver_manager *mgr = &drv_mgr;
+	struct drvmgr *mgr = &drvmgr;
 	struct drvmgr_dev *subdev, **pprev;
 	int err;

Index: cpukit/libdrvmgr/drvmgr.c
===================================================================
--- cpukit/libdrvmgr/drvmgr.c	(revision bf2c3f8baf2fcf8518b23eee9f886a12811dd5f9)
+++ cpukit/libdrvmgr/drvmgr.c	(revision bb2f2200aa144f96bdb3172bdaedf4ec82eac82b)
@@ -26,5 +26,5 @@
 #endif
 
-struct rtems_driver_manager drv_mgr = {
+struct drvmgr drvmgr = {
 	.level =		0,
 	.initializing_objs =	0,
@@ -55,9 +55,9 @@
 
 static int do_bus_init(
-	struct rtems_driver_manager *mgr,
+	struct drvmgr *mgr,
 	struct drvmgr_bus *bus,
 	int level);
 static int do_dev_init(
-	struct rtems_driver_manager *mgr,
+	struct drvmgr *mgr,
 	struct drvmgr_dev *dev,
 	int level);
@@ -67,5 +67,5 @@
 void _DRV_Manager_init_level(int level)
 {
-	struct rtems_driver_manager *mgr = &drv_mgr;
+	struct drvmgr *mgr = &drvmgr;
 
 	if (mgr->level >= level)
@@ -86,5 +86,5 @@
 	struct drvmgr_drv_reg_func *drvreg;
 
 	/* drv_mgr is already initialized statically by compiler except
 	 * the lock
 	 */
@@ -106,5 +106,5 @@
 void drvmgr_init_update(void)
 {
-	struct rtems_driver_manager *mgr = &drv_mgr;
+	struct drvmgr *mgr = &drvmgr;
 	struct drvmgr_bus *bus;
 	struct drvmgr_dev *dev;
@@ -184,5 +184,5 @@
 /* Take bus into next level */
 static int do_bus_init(
-	struct rtems_driver_manager *mgr,
+	struct drvmgr *mgr,
 	struct drvmgr_bus *bus,
 	int level)
@@ -243,5 +243,5 @@
 /* Take device to initialization level 1 */
 static int do_dev_init(
-	struct rtems_driver_manager *mgr,
+	struct drvmgr *mgr,
 	struct drvmgr_dev *dev,
 	int level)
@@ -318,5 +318,5 @@
 int drvmgr_root_drv_register(struct drvmgr_drv *drv)
 {
-	struct rtems_driver_manager *mgr = &drv_mgr;
+	struct drvmgr *mgr = &drvmgr;
 	struct drvmgr_dev *root = &mgr->root_dev;
 
@@ -347,5 +347,5 @@
 int drvmgr_drv_register(struct drvmgr_drv *drv)
 {
-	struct rtems_driver_manager *mgr = &drv_mgr;
+	struct drvmgr *mgr = &drvmgr;
 
 	/* All drivers must have been registered before start of init, 
@@ -455,5 +455,5 @@
 		struct drvmgr_dev *dev)
 {
-	struct rtems_driver_manager *mgr = &drv_mgr;
+	struct drvmgr *mgr = &drvmgr;
 	struct drvmgr_drv *drv;
 
@@ -474,5 +474,5 @@
 int drvmgr_dev_register(struct drvmgr_dev *dev)
 {
-	struct rtems_driver_manager *mgr = &drv_mgr;
+	struct drvmgr *mgr = &drvmgr;
 	struct drvmgr_drv *drv;
 	struct drvmgr_bus *bus = dev->parent;
@@ -569,5 +569,5 @@
 int drvmgr_bus_register(struct drvmgr_bus *bus)
 {
-	struct rtems_driver_manager *mgr = &drv_mgr;
+	struct drvmgr *mgr = &drvmgr;
 	struct drvmgr_bus *bus_up;
 
@@ -86,5 +86,5 @@
 	struct drvmgr_drv_reg_func *drvreg;
 
-	/* drv_mgr is already initialized statically by compiler except
+	/* drvmgr is already initialized statically by compiler except
 	 * the lock
 	 */